﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using LogicModule.Nodes.TestHelper;
using LogicModule.ObjectModel;
using LogicNodesSDK.Logic.Examples;
using NUnit.Framework;

namespace ExampleNodesTest
{
  [TestFixture]
  class ColorConverterTest
  {
    private INodeContext context;
    private ColorConverter node;

    public ColorConverterTest()
    {
      context = TestNodeContext.Create();
    }

    [SetUp]
    public void ColorInverterTestSetUp()
    {
      node = new ColorConverter(context);
    }

    [TearDown]
    public void ColorInverterTestTearDown()
    {
      node = null;
    }

    [Test]
    public void ThreeToOneTest()
    {
      node.Direction.Value = "DirectionThreeToOne";
      
      Assert.AreEqual(3, node.Inputs.Count);
      Assert.AreEqual(1, node.Outputs.Count);
      
      node.Inputs[0].Value = 0x11;
      node.Inputs[1].Value = 0x22;
      node.Inputs[2].Value = 0x33;

      node.Execute();

      Assert.AreEqual(0x112233, node.Outputs[0].Value);
    }

    [Test]
    public void OneToThreeTest()
    {
      node.Direction.Value = "DirectionOneToThree";
      
      Assert.AreEqual(1, node.Inputs.Count);
      Assert.AreEqual(3, node.Outputs.Count);
      
      node.Inputs[0].Value = 0x332211;

      node.Execute();

      Assert.AreEqual(0x33, node.Outputs[0].Value);
      Assert.AreEqual(0x22, node.Outputs[1].Value);
      Assert.AreEqual(0x11, node.Outputs[2].Value);
    }
  }
}
